@@ -9,6 +9,9 @@ import os
 
 from models_cisco import IOSHostnameLine, IOSRouteLine, IOSIntfLine
 from models_cisco import IOSAccessLine, IOSIntfGlobal
+from models_cisco import IOSAaaLoginAuthenticationLine
+from models_cisco import IOSAaaEnableAuthenticationLine
+from models_cisco import IOSAaaCommandsAuthorizationLine
 from models_cisco import IOSCfgLine
 
 
@@ -33,7 +36,7 @@ from models_cisco import IOSCfgLine
 """
 
 ## Docstring props: http://stackoverflow.com/a/1523456/667301
-__version_tuple__ = (1,1,7)
+__version_tuple__ = (1,1,8)
 __version__ = '.'.join(map(str, __version_tuple__))
 __email__ = "mike /at\ pennington [dot] net"
 __author__ = "David Michael Pennington <{0}>".format(__email__)
@@ -2101,7 +2104,9 @@ def ConfigLineFactory(text="", comment_delimiter="!", syntax='ios'):
     #classes = [j for (i,j) in globals().iteritems() if isinstance(j, TypeType) and issubclass(j, BaseCfgLine)]
 
     ## Manual and simple
-    classes = [IOSIntfLine, IOSRouteLine, IOSAccessLine,
+    classes = [IOSIntfLine, IOSRouteLine, IOSAccessLine, 
+        IOSAaaLoginAuthenticationLine, IOSAaaEnableAuthenticationLine,
+        IOSAaaCommandsAuthorizationLine,
         IOSHostnameLine, IOSIntfGlobal, IOSCfgLine]  # This is simple
     for cls in classes:
         if cls.is_object_for(text):
